package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.AmsDispatchSaleOrderMapper;
import com.steerinfo.dil.model.AmsDispatchSaleOrder;
import com.steerinfo.dil.service.IAmsDispatchSaleOrderService;
import com.steerinfo.dil.util.MapRemoveUtil;
import com.steerinfo.framework.mapper.IBaseMapper;
import com.steerinfo.framework.service.impl.BaseServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.*;

/**
 * AmsDispatchSaleOrder服务实现：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-09-10 03:59
 * 类描述
 * 修订历史：
 * 日期：2021-09-10
 * 作者：generator
 * 参考：
 * 描述：AmsDispatchSaleOrder服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "amsDispatchSaleOrderService")
public class AmsDispatchSaleOrderServiceImpl extends BaseServiceImpl<AmsDispatchSaleOrder, BigDecimal> implements IAmsDispatchSaleOrderService {

    @Autowired
    private AmsDispatchSaleOrderMapper amsDispatchSaleOrderMapper;

    @Override
    protected IBaseMapper<AmsDispatchSaleOrder, BigDecimal> getMapper() {
        return amsDispatchSaleOrderMapper;
    }

    public List<Map<String, Object>> getOpenDispatchSaleOrder(Map<String, Object> mapValue) {
        return amsDispatchSaleOrderMapper.getOpenDispatchSaleOrder(mapValue);
    }

    /**
     * 查询最大id
     * @return
     */
    @Override
    public BigDecimal selectMaxId() {

        return amsDispatchSaleOrderMapper.selectOtherId();
    }

    public int insert(AmsDispatchSaleOrder ad) {
        ad.setDispatchTime(new Date());
        ad.setInsertTime(new Date());
        ad.setInsertUsername("admin");
        return amsDispatchSaleOrderMapper.insertSelective(ad);
    }

    /**
     * 查询app端公开抢单
     * @return
     */
    @Override
    public List<Map<String, Object>> getDispatchSaleOrderList() {
        List<Map<String, Object>> dispatchSaleOrderList = amsDispatchSaleOrderMapper.getDispatchSaleOrderList();
        for (Map<String,Object> map: dispatchSaleOrderList) {
            Date dispatchDealTime = (Date) map.get("dispatchDealTime");
            BigDecimal dispatchId = (BigDecimal) map.get("dispatchId");
            String isDeal;
            if (dispatchDealTime == null) {
                isDeal = "已成交";
            }
            else {
                isDeal = "未成交";
            }
            map.put("isDeal",isDeal);
            // 先把map中的key-value放到新的saleMap里面
            Map<String,Object> saleMap = new HashMap<>();
            saleMap.putAll(map);
            // 使用Map清空工具迭代删除map中的所有key-value
            MapRemoveUtil.removeMap(map);
            List<Map<String, Object>> materialMessages = amsDispatchSaleOrderMapper.getMaterialMessages(dispatchId);
            // 将已经清空的map里面put进一个map和一个list<Map>
            map.put("materialMessages",materialMessages);
            map.put("saleMap",saleMap);
        }
        return dispatchSaleOrderList;
    }

    /**
     * 抢单/接收订单
     * @param dispatchId
     * @param carrierId
     * @return
     */
    @Override
    public int lockDispatchSaleOrder(BigDecimal dispatchId, BigDecimal carrierId) {
        AmsDispatchSaleOrder amsDispatchSaleOrder = amsDispatchSaleOrderMapper.selectByPrimaryKey(dispatchId);
        amsDispatchSaleOrder.setDispatchDealTime(new Date());
        amsDispatchSaleOrder.setCarrierId(carrierId);
        amsDispatchSaleOrder.setDispatchStatus(new BigDecimal(1));
        int result = amsDispatchSaleOrderMapper.updateByPrimaryKeySelective(amsDispatchSaleOrder);
        return result;
    }
}
